@@ -4,26 +4,17 @@ import os
 import re
 import shutil
 import sys
-import lxml.etree  # type: ignore
-from py4j.protocol import Py4JJavaError  # type: ignore
 from collections import OrderedDict
+from dataclasses import astuple, dataclass
 from http.client import HTTPResponse
 from inspect import Traceback
 from itertools import chain
 from subprocess import check_output
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    IO,
-    Iterable,
-    List,
-    Set,
-    Tuple,
-    Union,
-)
+from typing import IO, Any, Callable, Dict, Iterable, List, Set, Tuple, Union
 from urllib.request import urlopen
-from dataclasses import astuple, dataclass
+
+import lxml.etree  # type: ignore
+from py4j.protocol import Py4JJavaError  # type: ignore
 from pyspark.java_gateway import launch_gateway  # type: ignore
 from pyspark.sql import SparkSession  # type: ignore
 
@@ -76,8 +67,8 @@ def iter_links(url: str) -> Iterable[str]:
     http_response_io: HTTPResponse
     with urlopen(url) as http_response:
         html: str = str(http_response.read(), encoding="utf-8")
-        root: lxml.etree.Element = lxml.etree.HTML(html)
-    element: lxml.etree.Element
+        root: Any = lxml.etree.HTML(html)
+    element: Any
     for element in root.findall(".//a"):
         if element.attrib.get("href", ""):
             yield element.attrib["href"]
@@ -133,6 +124,9 @@ def _line_is_not_empty(line: str) -> bool:
     return True if line.strip() else False
 
 
+_UNDEFINED: object = object()
+
+
 class SparkDefaults:
     __slots__ = ("_dict",)
 
@@ -147,6 +141,12 @@ class SparkDefaults:
     def __delitem__(self, key: str) -> None:
         del self._dict[key]
 
+    def pop(self, key: str, default: Any = _UNDEFINED) -> Any:
+        if default is _UNDEFINED:
+            return self._dict.pop(key)
+        else:
+            return self._dict.pop(key, default)
+
     def __setitem__(self, key: str, values: Union[Iterable[str], str]) -> None:
         if not isinstance(values, set):
             if isinstance(values, str):
@@ -275,7 +275,9 @@ def clear_ivy_cache() -> None:
         pass
 
 
-def configure_defaults(use_localstack: bool = True) -> None:
+def configure_defaults(
+    use_localstack: bool = True, conf: Iterable[str] = ()
+) -> None:
     """
     This function alters $SPARK_HOME/conf/spark-defaults.conf so that pyspark
     will use localstack in lieu of AWS endpoints for s3 interactions.
@@ -287,23 +289,37 @@ def configure_defaults(use_localstack: bool = True) -> None:
         add_jar(
             f"org.apache.hadoop:hadoop-aws:{hadoop_version}", spark_defaults
         )
-        spark_defaults[
-            "spark.hadoop.fs.s3.impl"
-        ] = "org.apache.hadoop.fs.s3a.S3AFileSystem"
-        spark_defaults["spark.hadoop.fs.s3a.connection.ssl.enabled"] = "false"
-        spark_defaults["spark.hadoop.fs.s3a.attempts.maximum"] = "3"
-        spark_defaults["spark.hadoop.fs.s3a.change.detection.mode"] = "none"
+        spark_defaults["spark.hadoop.fs.s3.impl"] = (
+            "org.apache.hadoop.fs.s3a.S3AFileSystem"
+        )
         spark_defaults["spark.hadoop.fs.s3a.path.style.access"] = "true"
         spark_defaults["spark.hadoop.fs.s3a.fast.upload"] = "true"
         spark_defaults["spark.hadoop.fs.s3a.fast.upload.buffer"] = "bytebuffer"
+        spark_defaults["spark.hadoop.fs.s3a.change.detection.mode"] = "none"
+        spark_defaults["spark.hadoop.fs.s3a.attempts.maximum"] = "3"
         if use_localstack:
+            spark_defaults["spark.hadoop.fs.s3a.connection.ssl.enabled"] = (
+                "false"
+            )
             spark_defaults["spark.hadoop.fs.s3a.endpoint"] = "localhost:4566"
             spark_defaults["spark.hadoop.fs.s3a.access.key"] = "accesskey"
             spark_defaults["spark.hadoop.fs.s3a.secret.key"] = "secretkey"
+            spark_defaults["spark.driver.host"] = "localstack"
         else:
-            del spark_defaults["spark.hadoop.fs.s3a.endpoint"]
-            del spark_defaults["spark.hadoop.fs.s3a.access.key"]
-            del spark_defaults["spark.hadoop.fs.s3a.secret.key"]
+            spark_defaults.pop(
+                "spark.hadoop.fs.s3a.connection.ssl.enabled", None
+            )
+            spark_defaults.pop("spark.hadoop.fs.s3a.endpoint", None)
+            spark_defaults.pop("spark.hadoop.fs.s3a.access.key", None)
+            spark_defaults.pop("spark.hadoop.fs.s3a.secret.key", None)
+        configuration: str
+        for configuration in conf:
+            key: str
+            value: str
+            separator: str
+            key, separator, value = configuration.partition("=")
+            if separator:
+                spark_defaults[key] = value
     print("Success!")
 
 
@@ -323,9 +339,18 @@ def main() -> None:
         action="store_const",
         help="Configure S3 only (don't connect to localstack)",
     )
+    parser.add_argument(
+        "--conf",
+        default=[],
+        type=str,
+        action="append",
+        help="Additional spark configurations to set",
+    )
     namespace: argparse.Namespace = parser.parse_args()
     assert namespace
-    configure_defaults(use_localstack=(not namespace.non_local))
+    configure_defaults(
+        use_localstack=(not namespace.non_local), conf=namespace.conf
+    )
 
 
 if __name__ == "__main__":
